Documentation
¶
Overview ¶
Package http provides adapters to render gomponents in http handlers.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Adapt ¶
func Adapt(h Handler) http.HandlerFunc
Adapt a Handler to a http.HandlerFunc. The returned g.Node is rendered to the http.ResponseWriter, in both normal and error cases. If the Handler returns an error, and it implements a "StatusCode() int" method, that HTTP status code is sent in the response header. Otherwise, the status code http.StatusInternalServerError (500) is used.
Example ¶
package main
import (
"net/http"
g "github.com/maragudk/gomponents"
ghttp "github.com/maragudk/gomponents/http"
)
func main() {
h := ghttp.Adapt(func(w http.ResponseWriter, r *http.Request) (g.Node, error) {
return g.El("div"), nil
})
mux := http.NewServeMux()
mux.Handle("/", h)
}
Types ¶
Click to show internal directories.
Click to hide internal directories.